.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`color`
====================
.. automodule:: skimage.color

.. currentmodule:: skimage.color
.. autosummary::

   skimage.color.convert_colorspace
   skimage.color.guess_spatial_dimensions
   skimage.color.rgb2hsv
   skimage.color.hsv2rgb
   skimage.color.rgb2xyz
   skimage.color.xyz2rgb
   skimage.color.rgb2rgbcie
   skimage.color.rgbcie2rgb
   skimage.color.rgb2grey
   skimage.color.rgb2gray
   skimage.color.gray2rgb
   skimage.color.grey2rgb
   skimage.color.xyz2lab
   skimage.color.lab2xyz
   skimage.color.lab2rgb
   skimage.color.rgb2lab
   skimage.color.rgb2hed
   skimage.color.hed2rgb
   skimage.color.lab2lch
   skimage.color.lch2lab
   skimage.color.rgb2yuv
   skimage.color.yuv2rgb
   skimage.color.rgb2yiq
   skimage.color.yiq2rgb
   skimage.color.rgb2ypbpr
   skimage.color.ypbpr2rgb
   skimage.color.rgb2ycbcr
   skimage.color.ycbcr2rgb
   skimage.color.rgb2ydbdr
   skimage.color.ydbdr2rgb
   skimage.color.separate_stains
   skimage.color.combine_stains
   skimage.color.label2rgb
   skimage.color.deltaE_cie76
   skimage.color.deltaE_ciede94
   skimage.color.deltaE_ciede2000
   skimage.color.deltaE_cmc



convert_colorspace
------------------

.. autofunction:: skimage.color.convert_colorspace

guess_spatial_dimensions
------------------------

.. autofunction:: skimage.color.guess_spatial_dimensions

rgb2hsv
-------

.. autofunction:: skimage.color.rgb2hsv

hsv2rgb
-------

.. autofunction:: skimage.color.hsv2rgb

rgb2xyz
-------

.. autofunction:: skimage.color.rgb2xyz

xyz2rgb
-------

.. autofunction:: skimage.color.xyz2rgb

rgb2rgbcie
----------

.. autofunction:: skimage.color.rgb2rgbcie

rgbcie2rgb
----------

.. autofunction:: skimage.color.rgbcie2rgb

rgb2grey
--------

.. autofunction:: skimage.color.rgb2grey

rgb2gray
--------

.. autofunction:: skimage.color.rgb2gray

gray2rgb
--------

.. autofunction:: skimage.color.gray2rgb

grey2rgb
--------

.. autofunction:: skimage.color.grey2rgb

xyz2lab
-------

.. autofunction:: skimage.color.xyz2lab

lab2xyz
-------

.. autofunction:: skimage.color.lab2xyz

lab2rgb
-------

.. autofunction:: skimage.color.lab2rgb

rgb2lab
-------

.. autofunction:: skimage.color.rgb2lab

rgb2hed
-------

.. autofunction:: skimage.color.rgb2hed

hed2rgb
-------

.. autofunction:: skimage.color.hed2rgb

lab2lch
-------

.. autofunction:: skimage.color.lab2lch

lch2lab
-------

.. autofunction:: skimage.color.lch2lab

rgb2yuv
-------

.. autofunction:: skimage.color.rgb2yuv

yuv2rgb
-------

.. autofunction:: skimage.color.yuv2rgb

rgb2yiq
-------

.. autofunction:: skimage.color.rgb2yiq

yiq2rgb
-------

.. autofunction:: skimage.color.yiq2rgb

rgb2ypbpr
---------

.. autofunction:: skimage.color.rgb2ypbpr

ypbpr2rgb
---------

.. autofunction:: skimage.color.ypbpr2rgb

rgb2ycbcr
---------

.. autofunction:: skimage.color.rgb2ycbcr

ycbcr2rgb
---------

.. autofunction:: skimage.color.ycbcr2rgb

rgb2ydbdr
---------

.. autofunction:: skimage.color.rgb2ydbdr

ydbdr2rgb
---------

.. autofunction:: skimage.color.ydbdr2rgb

separate_stains
---------------

.. autofunction:: skimage.color.separate_stains

combine_stains
--------------

.. autofunction:: skimage.color.combine_stains

label2rgb
---------

.. autofunction:: skimage.color.label2rgb

deltaE_cie76
------------

.. autofunction:: skimage.color.deltaE_cie76

deltaE_ciede94
--------------

.. autofunction:: skimage.color.deltaE_ciede94

deltaE_ciede2000
----------------

.. autofunction:: skimage.color.deltaE_ciede2000

deltaE_cmc
----------

.. autofunction:: skimage.color.deltaE_cmc

